@@ -113,6 +113,8 @@ int main (int argc, char *argv[])
 	struct type_201 *t201 = (struct type_201 *) buff;
 	struct type_202 *t202 = (struct type_202 *) buff;
 	struct type_203 *t203 = (struct type_203 *) buff;
+	/* type 203_v0 */
+	/* type 203_v1 */
 	struct ch_struct *pchs = t203->channels;
 	struct type_204 *t204 = (struct type_204 *) buff;
 	struct type_205 *t205 = (struct type_205 *) buff;
@@ -338,7 +340,9 @@ int main (int argc, char *argv[])
 		/* ** Type-203 record? ** */
 		else if (strncmp (t1->recId, "203", 3) == 0)
 			{
-			nbuff = sizeof (struct type_203) - k;
+			nbuff = (strncmp (t203->version_no, "00", 2) == 0)
+			      ? sizeof (struct type_203_v0) - k
+			      : sizeof (struct type_203_v1) - k;
 			countt[14]++;		/* Increment record count */
 			}
 		/* ** Type-204 record? ** */
