@@ -84,15 +84,28 @@ struct c_block *f,*t;           /* f (from) is source pointer
     if (f->adhoc_amp != NULLFLOAT)
         t->adhoc_amp = f->adhoc_amp;
 
-    if (f->ionosphere.ref != NULLINT)
+    if (f->ionosphere.ref != NULLFLOAT)
         t->ionosphere.ref = f->ionosphere.ref;
 
-    if (f->ionosphere.rem != NULLINT)
+    if (f->ionosphere.rem != NULLFLOAT)
         t->ionosphere.rem = f->ionosphere.rem;
 
     if (f->t_cohere != NULLFLOAT)
         t->t_cohere = f->t_cohere;
 
+    if (f->dc_block != NULLINT)
+        t->dc_block = f->dc_block;
+
+    if (f->optimize_closure != NULLINT)
+        t->optimize_closure = f->optimize_closure;
+
+    if (f->nsamplers != NULLINT)
+        {
+        t->nsamplers = f->nsamplers;
+        for (i=0; i<f->nsamplers; i++)
+            t->psamplers[i] = f->psamplers[i];
+        strcpy (t->sampler_codes, f->sampler_codes);
+        }
 
     if (f->adhoc_poly[0] != NULLFLOAT)
         for (i=0; i<6; i++)
