@@ -89,8 +89,8 @@ fill_param (struct scan_struct *ovex,
     param->bocf_period = ivex->bocf_period;
                                         /* calculate ap length in playback time sysclks */
     ap_in_sysclks = rint ((double)param->acc_period * 32e6 / param->speedup);
-
-    if ((ap_in_sysclks % param->bocf_period) != 0)
+                                        // bocf_period only used in hardware correlator
+    if ((ap_in_sysclks % param->bocf_period) != 0 && param->corr_type == MK4HDW)
         {
         msg ("Error, AP seems not to be integral number of frames (%d/%d)",
                     2, ap_in_sysclks, param->bocf_period);
