@@ -170,7 +170,7 @@ char **argv;
         while (fset.file[++fno].type > 0)
             {
             fs = fset.file + fno;
-            msg ("Encountered type %d file", -1, fs->type);
+            msg ("Encountered type %d file:  %s", -1, fs->type, fs->name);
                                         /* Interested only in type 1 files */
             if (fs->type != 1) continue;
                                         /* If this is a refringe, proceed only */
