@@ -92,5 +92,8 @@ init_tokens ()
     tokenize (T_COHERE_,    "t_cohere",   FLOAT_PARAM);
     tokenize (IONOSPHERE_,  "ionosphere", FLOAT_PARAM);
     tokenize (DELAY_OFFS_,  "delay_offs", CHAN_PARAM);
+    tokenize (DC_BLOCK_,    "dc_block",   INT_PARAM);
+    tokenize (SAMPLERS_,    "samplers",   VECTOR_STRING_PARAM);
+    tokenize (OPTIMIZE_CLOSURE_, "optimize_closure", INT_PARAM);
     }
 
