@@ -108,7 +108,7 @@ struct type_221 **t221)
     time_t tm;
     struct tm *utc_now, *gmtime();
     float xr[2*MAXMAX], yr[2*MAXMAX], xmin, xmax, ymax, sec1, sec2, plotwidth;
-    float xpos, xposref,xposrem, ypos, spacing, offset, labelpos, lwid;
+    float xpos, xposref,xposrem, ypos, spacing, offset, labelpos, lwid, yplace;
     double max_dr_win, max_sb_win, max_mb_win;
     double plotstart, plotdur, plotend, totdur, tickinc, majinc, ticksize;
     float plot_time, trackerr, digitwidth, bandwidth, xstart, xend;
@@ -157,6 +157,11 @@ struct type_221 **t221)
         yr[i] = plot.d_rate[i];
         if (yr[i] > ymax) ymax = yr[i];
         }
+    if (ymax == 0.0)
+        {
+        msg ("overriding ymax of 0 in delay rate spectrum; data suspect", 2);
+        ymax = 1.0;
+        }
     cpgsvp (0.05, 0.80, 0.77, 0.95);
     cpgswin(xmin, xmax, 0.0, ymax);
     cpgsch (0.5);
@@ -198,6 +203,11 @@ struct type_221 **t221)
             yr[i] = plot.mb_amp[i];
             if (yr[i] > ymax) ymax = yr[i];
             }
+        if (ymax == 0.0)
+            {
+            msg ("overriding ymax of 0 in multiband delay plot; data suspect", 2);
+            ymax = 1.0;
+            }
         cpgswin (xmin, xmax, 0.0, ymax);
         cpgsch (0.5);
         cpgbox ("CMST", 0.0, 0.0, "CMST", 0.0, 0.0);
@@ -251,6 +261,11 @@ struct type_221 **t221)
         yr[i] = plot.sb_amp[i];
         if (yr[i] > ymax) ymax = yr[i];
         }
+    if (ymax == 0.0)
+        {
+        msg ("overriding ymax of 0 in singleband delay plot; data suspect", 2);
+        ymax = 1.0;
+        }
     cpgsvp (0.05, 0.35, 0.63, 0.74);
     cpgswin (xmin, xmax, 0.0, ymax);
     cpgsch (0.5);
@@ -318,6 +333,11 @@ struct type_221 **t221)
         if (yr[i] > ymax) ymax = yr[i];
         }
     ymax *= 1.2;
+    if (ymax == 0.0)
+        {
+        msg ("overriding ymax of 0 in crosspower spectrum plot; data suspect", 2);
+        ymax = 1.0;
+        }
     cpgsvp (0.43, 0.80, 0.63, 0.74);
     cpgswin(xstart, xend, 0.0, ymax);
     cpgsch (0.5);
@@ -407,7 +427,13 @@ struct type_221 **t221)
             cpgdraw (plot_time, 1.0);
             }
                                         /* Switch to segment/amplitude space */
-        cpgswin (0.0, (float)pass->num_ap, 0.0, (float)status.delres_max * 4.0);
+        ymax = (float)status.delres_max * 4.0;
+        if (ymax == 0.0)
+            {
+            msg ("overriding ymax of 0 in channel plot; data suspect", 2);
+            ymax = 1.0;
+            }
+        cpgswin (0.0, (float)pass->num_ap, 0.0, ymax);
         if (i == start_plot) 
             {
             cpgsch (0.5);
@@ -511,198 +537,238 @@ struct type_221 **t221)
         cpgsci (1);
         cpgbox ("AB", 0.0, 0.0, "BC", 0.0, 0.0);
                                         /* State count plots */
-        cpgsci (1);
-        cpgslw (1.0);
-        cpgsch (0.5);
-        cpgsvp (0.05 + (i-start_plot)*plotwidth, 0.05 + (i+1-start_plot)*plotwidth, 0.395, 0.41);
-        cpgswin (0.0, (float)pass->num_ap, -0.02, 0.02);
-        cpgbox ("BC", 0.0, 0.0, "BC", 0.0, 0.0);
+        if (status.stc_present)         // draw box only if at least one plot non-empty
+            {
+            cpgsci (1);
+            cpgslw (1.0);
+            cpgsch (0.5);
+            cpgsvp (0.05 + (i-start_plot)*plotwidth, 0.05 + (i+1-start_plot)*plotwidth, 0.395, 0.41);
+            cpgswin (0.0, (float)pass->num_ap, -0.02, 0.02);
+            cpgbox ("BC", 0.0, 0.0, "BC", 0.0, 0.0);
+            }
                                         /* Ref station green */
-        cpgsci (3);
-        maxj = 0;
-        for (j=0; j<np; j++) 
+        if (status.stc_present & 1)
             {
-            yr[j] = plot.seg_refbias_usb[i][j];
-            if (yr[j] < -1.0) ;
-            else if (yr[j] < -0.02)     /* Indicate limits with bars */
+            cpgsci (3);
+            maxj = 0;
+            for (j=0; j<np; j++) 
                 {
-                cpgmove (xr[j],-.015);
-                cpgdraw (xr[j],-.02);
+                yr[j] = plot.seg_refbias_usb[i][j];
+                if (yr[j] < -1.0) ;
+                else if (yr[j] < -0.02)     /* Indicate limits with bars */
+                    {
+                    cpgmove (xr[j],-.015);
+                    cpgdraw (xr[j],-.02);
+                    }
+                else if (yr[j] > 0.02) 
+                    {
+                    cpgmove (xr[j],.015);
+                    cpgdraw (xr[j],.02);
+                    }
+                if (yr[j] > -1.0) maxj = j;
                 }
-            else if (yr[j] > 0.02) 
-                {
-                cpgmove (xr[j],.015);
-                cpgdraw (xr[j],.02);
-                }
-            if (yr[j] > -1.0) maxj = j;
+            cpgline (maxj, xr, yr);
             }
-        cpgline (maxj, xr, yr);
                                         /* Rem station magenta */
-        cpgsci (6);
-        maxj = 0;
-        for (j=0; j<np; j++) 
+        if (status.stc_present & 2)
             {
-            yr[j] = plot.seg_rembias_usb[i][j];
-            if (yr[j] < -1.0) ;
-            else if (yr[j] < -0.02)     /* Indicate limits with bars */
+            cpgsci (6);
+            maxj = 0;
+            for (j=0; j<np; j++) 
                 {
-                cpgmove (xr[j],-.015);
-                cpgdraw (xr[j],-.02);
+                yr[j] = plot.seg_rembias_usb[i][j];
+                if (yr[j] < -1.0) ;
+                else if (yr[j] < -0.02)     /* Indicate limits with bars */
+                    {
+                    cpgmove (xr[j],-.015);
+                    cpgdraw (xr[j],-.02);
+                    }
+                else if (yr[j] > 0.02) 
+                    {
+                    cpgmove (xr[j],.015);
+                    cpgdraw (xr[j],.02);
+                    }
+                if (yr[j] > -1.0) maxj = j;
                 }
-            else if (yr[j] > 0.02) 
-                {
-                cpgmove (xr[j],.015);
-                cpgdraw (xr[j],.02);
-                }
-            if (yr[j] > -1.0) maxj = j;
+            cpgline (maxj, xr, yr);
             }
-        cpgline (maxj, xr, yr);
                                         /* LSB */
-        cpgsci (1);
-        cpgslw (1.0);
-        cpgsch (0.5);
-        cpgsvp (0.05 + (i-start_plot)*plotwidth, 0.05 + (i+1-start_plot)*plotwidth, 0.38, 0.395);
-        cpgswin (0.0, (float)pass->num_ap, -0.02, 0.02);
-        cpgbox ("BC", 0.0, 0.0, "BC", 0.0, 0.0);
+        if (status.stc_present)         // draw box only if at least one plot non-empty
+            {
+            cpgsci (1);
+            cpgslw (1.0);
+            cpgsch (0.5);
+            cpgsvp (0.05 + (i-start_plot)*plotwidth, 0.05 + (i+1-start_plot)*plotwidth, 0.38, 0.395);
+            cpgswin (0.0, (float)pass->num_ap, -0.02, 0.02);
+            cpgbox ("BC", 0.0, 0.0, "BC", 0.0, 0.0);
+            }
                                         /* Ref station green */
-        cpgsci (3);
-        maxj = 0;
-        for (j=0; j<np; j++) 
+        if (status.stc_present & 1)
             {
-            yr[j] = plot.seg_refbias_lsb[i][j];
-            if (yr[j] < -1.0) ;
-            else if (yr[j] < -0.02)     /* Indicate limits with bars */
+            cpgsci (3);
+            maxj = 0;
+            for (j=0; j<np; j++) 
                 {
-                cpgmove (xr[j],-.015);
-                cpgdraw (xr[j],-.02);
+                yr[j] = plot.seg_refbias_lsb[i][j];
+                if (yr[j] < -1.0) ;
+                else if (yr[j] < -0.02)     /* Indicate limits with bars */
+                    {
+                    cpgmove (xr[j],-.015);
+                    cpgdraw (xr[j],-.02);
+                    }
+                else if (yr[j] > 0.02) 
+                    {
+                    cpgmove (xr[j],.015);
+                    cpgdraw (xr[j],.02);
+                    }
+                if (yr[j] > -1.0) maxj = j;
                 }
-            else if (yr[j] > 0.02) 
-                {
-                cpgmove (xr[j],.015);
-                cpgdraw (xr[j],.02);
-                }
-            if (yr[j] > -1.0) maxj = j;
+            cpgline (maxj, xr, yr);
             }
-        cpgline (maxj, xr, yr);
                                         /* Rem station magenta */
-        cpgsci (6);
-        maxj = 0;
-        for (j=0; j<np; j++) 
+        if (status.stc_present & 2)
             {
-            yr[j] = plot.seg_rembias_lsb[i][j];
-            if (yr[j] < -1.0) ;
-            else if (yr[j] < -0.02)     /* Indicate limits with bars */
+            cpgsci (6);
+            maxj = 0;
+            for (j=0; j<np; j++) 
                 {
-                cpgmove (xr[j],-.015);
-                cpgdraw (xr[j],-.02);
+                yr[j] = plot.seg_rembias_lsb[i][j];
+                if (yr[j] < -1.0) ;
+                else if (yr[j] < -0.02)     /* Indicate limits with bars */
+                    {
+                    cpgmove (xr[j],-.015);
+                    cpgdraw (xr[j],-.02);
+                    }
+                else if (yr[j] > 0.02) 
+                    {
+                    cpgmove (xr[j],.015);
+                    cpgdraw (xr[j],.02);
+                    }
+                if (yr[j] > -1.0) maxj = j;
                 }
-            else if (yr[j] > 0.02) 
-                {
-                cpgmove (xr[j],.015);
-                cpgdraw (xr[j],.02);
-                }
-            if (yr[j] > -1.0) maxj = j;
+            cpgline (maxj, xr, yr);
             }
-        cpgline (maxj, xr, yr);
                                         /* Big versus small */
-        cpgsci (1);
-        cpgslw (1.0);
-        cpgsch (0.5);
-        cpgsvp (0.05 + (i-start_plot)*plotwidth, 0.05 + (i+1-start_plot)*plotwidth, 0.36, 0.38);
-        cpgswin (0.0, (float)pass->num_ap, 0.54, 0.72);
-        cpgbox ("BC", 0.0, 0.0, "BC", 0.0, 0.0);
+        if (status.stc_present)         // draw box only if at least one plot non-empty
+            {
+            cpgsci (1);
+            cpgslw (1.0);
+            cpgsch (0.5);
+            cpgsvp (0.05 + (i-start_plot)*plotwidth, 0.05 + (i+1-start_plot)*plotwidth, 0.36, 0.38);
+            cpgswin (0.0, (float)pass->num_ap, 0.54, 0.72);
+            cpgbox ("BC", 0.0, 0.0, "BC", 0.0, 0.0);
+            }
+        if (status.stc_present & 1)
+            {
                                         /* Ref station blue */
-        cpgsci (4);
-        maxj = 0;
-        for (j=0; j<np; j++) 
-            {                           /* Check range of data */
-            yr[j] = plot.seg_refscnt_usb[i][j];
-            if (yr[j] < 0.0) ;
-            else if (yr[j] < 0.54)     /* Indicate limits with bars */
-                {
-                cpgmove (xr[j],0.56);
-                cpgdraw (xr[j],0.54);
+            cpgsci (4);
+            maxj = 0;
+            for (j=0; j<np; j++) 
+                {                           /* Check range of data */
+                yr[j] = plot.seg_refscnt_usb[i][j];
+                if (yr[j] < 0.0) ;
+                else if (yr[j] < 0.54)     /* Indicate limits with bars */
+                    {
+                    cpgmove (xr[j],0.56);
+                    cpgdraw (xr[j],0.54);
+                    }
+                else if (yr[j] > 0.72) 
+                    {
+                    cpgmove (xr[j],0.70);
+                    cpgdraw (xr[j],0.72);
+                    }
+                if (yr[j] > 0.0) maxj = j;
                 }
-            else if (yr[j] > 0.72) 
-                {
-                cpgmove (xr[j],0.70);
-                cpgdraw (xr[j],0.72);
-                }
-            if (yr[j] > 0.0) maxj = j;
+            cpgline (maxj, xr, yr);
             }
-        cpgline (maxj, xr, yr);
                                         /* Rem station red */
-        cpgsci (2);
-        maxj = 0;
-        for (j=0; j<np; j++) 
-            {                           /* Check range of data */
-            yr[j] = plot.seg_remscnt_usb[i][j];
-            if (yr[j] < 0.0) ;
-            else if (yr[j] < 0.54)     /* Indicate limits with bars */
-                {
-                cpgmove (xr[j],0.56);
-                cpgdraw (xr[j],0.54);
+        if (status.stc_present & 2)
+            {
+            cpgsci (2);
+            maxj = 0;
+            for (j=0; j<np; j++) 
+                {                           /* Check range of data */
+                yr[j] = plot.seg_remscnt_usb[i][j];
+                if (yr[j] < 0.0) ;
+                else if (yr[j] < 0.54)     /* Indicate limits with bars */
+                    {
+                    cpgmove (xr[j],0.56);
+                    cpgdraw (xr[j],0.54);
+                    }
+                else if (yr[j] > 0.72) 
+                    {
+                    cpgmove (xr[j],0.70);
+                    cpgdraw (xr[j],0.72);
+                    }
+                if (yr[j] > 0.0) maxj = j;
                 }
-            else if (yr[j] > 0.72) 
-                {
-                cpgmove (xr[j],0.70);
-                cpgdraw (xr[j],0.72);
-                }
-            if (yr[j] > 0.0) maxj = j;
+            cpgline (maxj, xr, yr);
             }
-        cpgline (maxj, xr, yr);
                                         /* LSB */
-        cpgsci (1);
-        cpgslw (1.0);
-        cpgsch (0.5);
-        cpgsvp (0.05 + (i-start_plot)*plotwidth, 0.05 + (i+1-start_plot)*plotwidth, 0.34, 0.36);
-        cpgswin (0.0, (float)pass->num_ap, 0.54, 0.72);
-        cpgbox ("BC", 0.0, 0.0, "BC", 0.0, 0.0);
+        if (status.stc_present)         // draw box only if at least one plot non-empty
+            {
+            cpgsci (1);
+            cpgslw (1.0);
+            cpgsch (0.5);
+            cpgsvp (0.05 + (i-start_plot)*plotwidth, 0.05 + (i+1-start_plot)*plotwidth, 0.34, 0.36);
+            cpgswin (0.0, (float)pass->num_ap, 0.54, 0.72);
+            cpgbox ("BC", 0.0, 0.0, "BC", 0.0, 0.0);
+            }
                                         /* Ref station blue */
-        cpgsci (4);
-        maxj = 0;
-        for (j=0; j<np; j++) 
+        if (status.stc_present & 1)
             {
-            yr[j] = plot.seg_refscnt_lsb[i][j];
-            if (yr[j] < 0.0) ;
-            else if (yr[j] < 0.54)     /* Indicate limits with bars */
+            cpgsci (4);
+            maxj = 0;
+            for (j=0; j<np; j++) 
                 {
-                cpgmove (xr[j],0.56);
-                cpgdraw (xr[j],0.54);
+                yr[j] = plot.seg_refscnt_lsb[i][j];
+                if (yr[j] < 0.0) ;
+                else if (yr[j] < 0.54)     /* Indicate limits with bars */
+                    {
+                    cpgmove (xr[j],0.56);
+                    cpgdraw (xr[j],0.54);
+                    }
+                else if (yr[j] > 0.72) 
+                    {
+                    cpgmove (xr[j],0.70);
+                    cpgdraw (xr[j],0.72);
+                    }
+                if (yr[j] > 0.0) maxj = j;
                 }
-            else if (yr[j] > 0.72) 
-                {
-                cpgmove (xr[j],0.70);
-                cpgdraw (xr[j],0.72);
-                }
-            if (yr[j] > 0.0) maxj = j;
+            cpgline (maxj, xr, yr);
             }
-        cpgline (maxj, xr, yr);
                                         /* Rem station red */
-        cpgsci (2);
-        maxj = 0;
-        for (j=0; j<np; j++) 
+        if (status.stc_present & 2)
             {
-            yr[j] = plot.seg_remscnt_lsb[i][j];
-            if (yr[j] < 0.0) ;
-            else if (yr[j] < 0.54)     /* Indicate limits with bars */
+            cpgsci (2);
+            maxj = 0;
+            for (j=0; j<np; j++) 
                 {
-                cpgmove (xr[j],0.56);
-                cpgdraw (xr[j],0.54);
+                yr[j] = plot.seg_remscnt_lsb[i][j];
+                if (yr[j] < 0.0) ;
+                else if (yr[j] < 0.54)     /* Indicate limits with bars */
+                    {
+                    cpgmove (xr[j],0.56);
+                    cpgdraw (xr[j],0.54);
+                    }
+                else if (yr[j] > 0.72) 
+                    {
+                    cpgmove (xr[j],0.70);
+                    cpgdraw (xr[j],0.72);
+                    }
+                if (yr[j] > 0.0) maxj = j;
                 }
-            else if (yr[j] > 0.72) 
-                {
-                cpgmove (xr[j],0.70);
-                cpgdraw (xr[j],0.72);
-                }
-            if (yr[j] > 0.0) maxj = j;
+            cpgline (maxj, xr, yr);
             }
-        cpgline (maxj, xr, yr);
+        yplace = (status.stc_present) ? 0.34 : 0.41;
+
                                         /* Phasecal phase plots */
         cpgsci (1);
         cpgslw (1.0);
         cpgsch (0.5);
-        cpgsvp (0.05 + (i-start_plot)*plotwidth, 0.05 + (i+1-start_plot)*plotwidth, 0.29, 0.34);
+        cpgsvp (0.05 + (i-start_plot)*plotwidth, 0.05 + (i+1-start_plot)*plotwidth, 
+                yplace - 0.05, yplace);
+        yplace -= 0.065;
                                         /* Draw tick marks on bottom edge, in */
                                         /* real seconds/minutes */
         xmin = plotstart;
@@ -719,7 +785,7 @@ struct type_221 **t221)
             }
                                         /* Back to AP space */
         cpgswin (0.0, (float)pass->num_ap, -180.0, 180.0);
-        cpgbox ("B", 0.0, 0.0, "B", 0.0, 0.0);
+        cpgbox ("BC", 0.0, 0.0, "B", 0.0, 0.0);
                                         /* Ref station green */
         cpgsci (3);
         cpgslw (lwid);
@@ -969,39 +1035,44 @@ struct type_221 **t221)
     psright (0.050,  0.429, "U");
     psleft  (0.000,  0.422, "Validity");
     psright (0.049,  0.413, "L");
-    psright (0.050,  0.399, "U");
-    psleft  (0.000,  0.392, "Bias");
-    psright (0.049,  0.385, "L");
-    psright (0.050,  0.365, "U");
-    psleft  (0.000,  0.355, "Level");
-    psright (0.049,  0.348, "L");
                                         /* Label for tape error plots */
     xpos = labelpos + 0.003;
+    if (status.stc_present)
+        {
+        psright (0.050,  0.399, "U");
+        psleft  (0.000,  0.392, "Bias");
+        psright (0.049,  0.385, "L");
+        psright (0.050,  0.365, "U");
+        psleft  (0.000,  0.355, "Level");
+        psright (0.049,  0.348, "L");
                                         /* Color coded stations for bias */
-    sprintf (buf, "%c", param.baseline[0]);
-    setgreen;
-    psleft (xpos, 0.39, buf);
-    sprintf (buf, "%c", param.baseline[1]);
-    setmagenta;
-    xpos += 0.015;
-    psleft (xpos, 0.39, buf);
-    xpos -= 0.015;
+        sprintf (buf, "%c", param.baseline[0]);
+        setgreen;
+        psleft (xpos, 0.39, buf);
+        sprintf (buf, "%c", param.baseline[1]);
+        setmagenta;
+        xpos += 0.015;
+        psleft (xpos, 0.39, buf);
+        xpos -= 0.015;
                                         /* Color coded stations for level */
-    sprintf (buf, "%c", param.baseline[0]);
-    setblue;
-    psleft (xpos, 0.355, buf);
-    sprintf (buf, "%c", param.baseline[1]);
-    setred;
-    xpos += 0.015;
-    psleft (xpos, 0.355, buf);
+        sprintf (buf, "%c", param.baseline[0]);
+        setblue;
+        psleft (xpos, 0.355, buf);
+        sprintf (buf, "%c", param.baseline[1]);
+        setred;
+        xpos += 0.015;
+        psleft (xpos, 0.355, buf);
+        }
                                         /* Color coded stations for phasecal */
+    xpos += 0.015;
+    ypos = (status.stc_present) ? 0.310 : 0.380;
     sprintf (buf, "%c", param.baseline[0]);
     setgreen;
-    psleft (xpos, 0.310, buf);
+    psleft (xpos, ypos, buf);
     sprintf (buf, "%c", param.baseline[1]);
     setmagenta;
     xpos += 0.015;
-    psleft (xpos, 0.310, buf);
+    psleft (xpos, ypos, buf);
     setblack;
                                         /* Relocate text if only one plot */
     if (nplots == 2) labelpos = 0.30;
@@ -1030,7 +1101,7 @@ struct type_221 **t221)
                                         /* and psleft macros, to support A4 paper */
                                         /* since pgplot coord system is letter */
         xpos = 0.05 + (i-start_plot)*plotwidth * 1.0304;
-        ypos = 0.275;
+        ypos = yplace;
         spacing = 0.0095;
         sprintf (buf, "%.2f", pass->pass_data[i].frequency);
         psleft (xpos, ypos, buf);
@@ -1276,7 +1347,7 @@ struct type_221 **t221)
     if (nplots > 2)
         {
         xpos = 1.0;
-        ypos = 0.275;
+        ypos = yplace;
         psright (xpos, ypos, "All");
         ypos -= spacing;
         sprintf (buf, "%.1f", status.resid_phase);
@@ -1288,15 +1359,15 @@ struct type_221 **t221)
         sprintf (buf, "%.1f", status.sbdbox[MAXFREQ]);
         psright (xpos, ypos, buf);
         }
-/*     ypos = 0.15; */
-    ypos = 0.130;
+    yplace -= 0.145;
+    ypos = yplace;
     pscat ("/Helvetica findfont 95 scalefont setfont\n");
     psleft (0.0, ypos, "Group delay (usec)"); ypos -= 0.01;
     psleft (0.0, ypos, "Sband delay (usec)"); ypos -= 0.01;
     psleft (0.0, ypos, "Phase delay (usec)"); ypos -= 0.01;
     psleft (0.0, ypos, "Delay rate (us/s)"); ypos -= 0.01;
     psleft (0.0, ypos, "Total phase (deg)");
-    ypos = 0.130;
+    ypos = yplace;
     sprintf (buf, "%.11E", fringe.t208->tot_mbd);
     psright (0.29, ypos, buf); ypos -= 0.01;
     sprintf (buf, "%.11E", fringe.t208->tot_sbd);
@@ -1307,13 +1378,13 @@ struct type_221 **t221)
     psright (0.29, ypos, buf); ypos -= 0.01;
     sprintf (buf, "%.1f", fringe.t208->totphase);
     psright (0.29, ypos, buf);
-    ypos = 0.130;
+    ypos = yplace;
     psleft (0.32, ypos, "Apriori delay (usec)"); ypos -= 0.01;
     psleft (0.32, ypos, "Apriori clock (usec)"); ypos -= 0.01;
     psleft (0.32, ypos, "Apriori clockrate (us/s)"); ypos -= 0.01;
     psleft (0.32, ypos, "Apriori rate (us/s)"); ypos -= 0.01;
     psleft (0.32, ypos, "Apriori accel (us/s/s)");
-    ypos = 0.130;
+    ypos = yplace;
     sprintf (buf, "%.11E", fringe.t208->adelay);
     psright (0.62, ypos, buf); ypos -= 0.01;
     sprintf (buf, "%.7E", fringe.t202->rem_clock - fringe.t202->ref_clock);
@@ -1325,13 +1396,13 @@ struct type_221 **t221)
     psright (0.62, ypos, buf); ypos -= 0.01;
     sprintf (buf, "%.11E", fringe.t208->aaccel);
     psright (0.62, ypos, buf); ypos -= 0.01;
-    ypos = 0.130;
+    ypos = yplace;
     psleft (0.65, ypos, "Resid mbdelay (usec)"); ypos -= 0.01;
     psleft (0.65, ypos, "Resid sbdelay (usec)"); ypos -= 0.01;
     psleft (0.65, ypos, "Resid phdelay (usec)"); ypos -= 0.01;
     psleft (0.65, ypos, "Resid rate (us/s)"); ypos -= 0.01;
     psleft (0.65, ypos, "Resid phase (deg)");
-    ypos = 0.130;
+    ypos = yplace;
     sprintf (buf, "%.5E", fringe.t208->resid_mbd);
     psright (0.90, ypos, buf); ypos -= 0.01;
     sprintf (buf, "%.5E", fringe.t208->resid_sbd);
@@ -1342,13 +1413,13 @@ struct type_221 **t221)
     psright (0.90, ypos, buf); ypos -= 0.01;
     sprintf (buf, "%.1f", fringe.t208->resphase);
     psright (0.90, ypos, buf);
-    ypos = 0.130;
+    ypos = yplace;
     psleft (0.92, ypos, "+/-"); ypos -= 0.01;
     psleft (0.92, ypos, "+/-"); ypos -= 0.01;
     psleft (0.92, ypos, "+/-"); ypos -= 0.01;
     psleft (0.92, ypos, "+/-"); ypos -= 0.01;
     psleft (0.92, ypos, "+/-");
-    ypos = 0.130;
+    ypos = yplace;
     sprintf (buf, "%.1E", fringe.t208->mbd_error);
     psright (1.0, ypos, buf); ypos -= 0.01;
     sprintf (buf, "%.1E", fringe.t208->sbd_error);
@@ -1359,7 +1430,9 @@ struct type_221 **t221)
     psright (1.0, ypos, buf); ypos -= 0.01;
     sprintf (buf, "%.1f", status.phase_err);
     psright (1.0, ypos, buf);
-    ypos = 0.080;
+    yplace -= 0.050;
+    ypos = yplace;
+    ypos -= 0.005;
     psleft (0.1, ypos, "RMS");
     psleft (0.15, ypos, "Theor.");
     psleft (0.23, ypos, "Amplitude");
@@ -1443,7 +1516,7 @@ struct type_221 **t221)
     else
         sprintf (buf, "t_cohere infinite");
     psleft (0.75, ypos, buf);
-    ypos = 0.025;
+    ypos -= 0.015;
 
     if (test_mode) strcpy (output_filename, "Suppressed by test mode");
     else strcpy (output_filename, fringename);
