@@ -50,7 +50,10 @@ int pol, fr, ap;
     double samp_per_ap, corrfact, rawcorr, factor, mean;
     double diff_delay, deltaf;
     int flagmask,
-        freq_no;
+        freq_no,
+        ibegin,
+        sindex;
+    int stnpol[2][4] = {0, 1, 0, 1, 0, 1, 1, 0}; // [stn][pol] = 0:L/X/H, 1:R/Y/V
     extern struct type_param param;
     extern struct type_status status;
 
@@ -319,6 +322,7 @@ int pol, fr, ap;
             status.ap_num[sb][fr]++;
             status.total_ap++;
             fb_fact = 1.0;          // may want to re-examine this assumption
+            theta = 0.0;            // no fractional bit induced error correction
 
             if (sb) 
                 {
@@ -337,6 +341,13 @@ int pol, fr, ap;
                 {
                 xp_spec[i].re = rawdatum->ld.spec[i].re;
                 xp_spec[i].im = rawdatum->ld.spec[i].im;
+                                    // filter out any nan's, if present
+                if (isnan (xp_spec[i].re) || isnan (xp_spec[i].im))
+                    {
+                    msg ("clearing nan's in visibility for ap %d fr %d lag %i", 2, ap, fr, i);
+                    xp_spec[i].re = 0.0;
+                    xp_spec[i].im = 0.0;
+                    }
                 }
             }
 
@@ -352,19 +363,25 @@ int pol, fr, ap;
                                         /* copy in half of the Xpower array */
                                         /* Weight each sideband by data fraction */
 
-        for (i = 1; i < nlags; i++)
-            {
-            if (sb == 0)
+                                        // skip 0th spectral pt if DC channel suppressed
+        ibegin = (pass->control.dc_block) ? 1 : 0;
+        if (sb == 0)
+            { 
+            for (i = ibegin; i < nlags; i++)
                 {
                 factor = fb_fact * datum->usbfrac;
                 S[i] = s_mult (c_mult (xp_spec[i], 
                         c_exp (theta * (double)(i-nlags/2))),factor);
                 }
-                                        /* LSB: conjugate, add phase offset */
-            else
+            }
+        else                            /* LSB: conjugate, add phase offset */
+            {
+            for (i = ibegin; i < nlags; i++)
                 {
                 factor = fb_fact * datum->lsbfrac;
-                S[nlags*4 - i] = s_mult (conju (c_mult (xp_spec[i], 
+                                        // DC goes into 1st element of the S array
+                sindex = i ? 4 * nlags - i : 0;
+                S[sindex] = s_mult (conju (c_mult (xp_spec[i], 
                                c_exp (theta * (double)(i-nlags/2) 
                              + status.lsb_phoff[0] - status.lsb_phoff[1]))),factor);
                 }
@@ -394,22 +411,32 @@ int pol, fr, ap;
     NORM_HACK_HOOK;
 #endif /* NORM_HACK_HOOK */
 
+                                        // corrections to phase as fn of freq based upon 
+                                        // delay calibrations
                                         // apply delay offset phase ramp
                                         // iff the offset is non-zero
     freq_no = fcode(pass->pass_data[fr].freq_code);
-    diff_delay = pass->control.delay_offs[freq_no].rem - pass->control.delay_offs[freq_no].ref;
-    if (diff_delay)
+    diff_delay = pass->control.delay_offs[freq_no].rem 
+               - pass->control.delay_offs[freq_no].ref;
+                                        // add in phase effects if multitone delays were extracted
+    if (pass->control.nsamplers && param.pc_mode[0] == MULTITONE 
+                                && param.pc_mode[1] == MULTITONE)      
+        diff_delay += 1e9 * datum->rem_sdata.mt_delay[stnpol[1][pol]] 
+                          - datum->ref_sdata.mt_delay[stnpol[0][pol]];
+
+    if (diff_delay != 0.0)              // apply only non-zero delay effects
         {
         for (i=1, j=4*nlags-1; i<nlags; i++, j--)
             {
                                         // calculate offset frequency of DC edge in
                                         // GHz from the reference frequency for USB
-            deltaf = 1e-3 * (fdata->frequency - param.ref_freq 
+                                        // for now (2011.10.5) don't phase ref to the ref freq
+            deltaf = 1e-3 * (/* fdata->frequency - param.ref_freq */
                            + i / (2e6 * param.samp_period * nlags));
                                         // apply phase ramp to spectral points 
             S[i] = c_mult (S[i], c_exp (2.0 * M_PI * diff_delay * deltaf));
                                         // ditto for LSB
-            deltaf = 1e-3 * (fdata->frequency - param.ref_freq 
+            deltaf = 1e-3 * (/* fdata->frequency - param.ref_freq */
                            - i / (2e6 * param.samp_period * nlags));
             S[j] = c_mult (S[j], c_exp (2.0 * M_PI * diff_delay * deltaf));
             }
@@ -427,7 +454,11 @@ int pol, fr, ap;
             if (j < 0) j += nlags*4;
                                         /* re-normalize back to single lag */
                                         /* (property of FFTs) */
-            datum->sbdelay[i] = s_mult (xcor[j], 1.0 / (nlags - 1.0));
+                                        // nlags-1 norm. iff zeroed-out DC
+            if (pass->control.dc_block)
+                datum->sbdelay[i] = s_mult (xcor[j], 1.0 / (nlags - 1.0));
+            else
+                datum->sbdelay[i] = s_mult (xcor[j], 1.0 / nlags);
             }
          }
                                         /* No data */
