@@ -48,10 +48,17 @@ struct c_block *cb_ptr;
     cb_ptr -> t_cohere        = NULLFLOAT;
     cb_ptr -> ionosphere.ref  = NULLFLOAT;
     cb_ptr -> ionosphere.rem  = NULLFLOAT;
+    cb_ptr -> dc_block        = NULLINT;  
+    cb_ptr -> nsamplers       = NULLINT;
+    cb_ptr -> sampler_codes[0]= NULL;
+    cb_ptr -> optimize_closure= NULLINT;  
 
     for (i=0; i<6; i++)
         cb_ptr -> adhoc_poly[i] = NULLFLOAT;
 
+    for (i=0; i<8; i++)
+        cb_ptr -> psamplers[i] = NULL;
+
     for (i=0; i<2; i++)
 	{
         cb_ptr -> baseline[i]  = WILDCARD;
