@@ -54,8 +54,10 @@ struct freq_corel *corel)
     struct mk4_sdata *sd;
     struct type_306 *t306;
     struct interp_sdata *isd;
+    extern struct type_status status;
                                         /* flag to control stc err message */
     first_mess = 1;
+    status.stc_present = 0;         // indicate neither station having state counts
     
     if (param->bits_sample == 2)
         {
@@ -103,6 +105,8 @@ struct freq_corel *corel)
             msg ("No stcount data for station %c", 1, sd->t300->id);
             continue;
             }
+                                    // indicate that this station has state counts
+        status.stc_present |= 1 << stn;
                                         /* Loop over channels */
                                         /* Assume that first 306 is like */
                                         /* all the rest, vis a vis chan order */
