@@ -34,21 +34,27 @@ struct type_pass *pass;
     double theta;
     extern struct type_param param;
     extern struct type_status status;
-                                        /* theta is in turns */
+                                        // theta is in rotations
 
                                         /* fringe rate * time from central epoch */
     theta = pass->pass_data[fr].frequency * dr 
                 * (param.acc_period * (ap + 0.5) + status.epoch_err[fr]);
 
-                                        /* rotate by differential phase cal */
-                                        /* Phasecal phases stored in radians */
-    theta += (status.pc_phase[fr][0] - status.pc_phase[fr][1]) / (2.0 * M_PI);
-
                                         /* Residual mbd effect at this freq */
-    theta += (pass->pass_data[fr].frequency - param.ref_freq + 0.125 * sb / status.sbd_sep) * mbd;
-                                        /* effect of non-integral sbd when SSB 
-                                         * correct phase to band center, based on delay */
+    if (pass->control.optimize_closure) // sacrifice mbd fit for less-noisy closure?
+        theta += mbd * (pass->pass_data[fr].frequency - param.ref_freq 
+                        + 0.125 * sb / status.sbd_sep);
+    else
+        {
+        theta += mbd * (pass->pass_data[fr].frequency - param.ref_freq);
+                                        /* effect of non-integral sbd iff SSB
+                                         * correct phase to dc edge, based on sb delay */
+        theta += (param.nlags - status.max_delchan + status.sbd_max / status.sbd_sep) * 0.125 * sb;
+        }
+    theta *= (-2.0 * M_PI);             // convert to radians
 
-    theta *= (-2.0 * M_PI);             /* convert to radians, and return a unit vector */
-    return(c_exp(theta));
+                                        // rotate by differential phase cal (already in radians)
+    theta += status.pc_phase[fr][1] - status.pc_phase[fr][0] ;
+
+    return (c_exp(theta));              // return unit phasor
     }
