@@ -12,8 +12,8 @@
 /****************************************************************/
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
-#include "data.h"
 #include "mk4_data.h"
 #include "fstruct.h"
 #include "fplot.h"
@@ -27,14 +27,12 @@ char *argv[];
     {
     int i, display, ret, mk4, size, quit;
     char c, *ps_file, *title[2], cmd[50];
-    struct data_fringe fringe3;
     struct mk4_fringe fringe4;
     fstruct *files;
     FILE *fp;
                                         /* Initialize.  No fstruct entry with a NULL */
                                         /* filename is valid ... don't need to clear */
                                         /* the whole structure */
-    fringe3.fplot_alloc = fringe3.alloc_5000 = FALSE;
     fringe4.nalloc = 0;
                                         /* Check for option flags, then fill in the */
                                         /* files structure array, checking the file */
